<?php

namespace QUI\ERP\Coupons\Products;

use QUI;
use QUI\ERP\Products\Product\Types\DigitalProduct;

/**
 * Class DigitalProduct
 *
 * Represents a non-physical product that does not require shipping.
 */
class CouponProductType extends DigitalProduct
{
    /**
     * Special fields for coupon products
     */
    const PRODUCT_FIELD_ID_TRANSFERABLE                    = 670;
    const PRODUCT_FIELD_ID_GENERATE_PDF                    = 671;
    const PRODUCT_FIELD_ID_COUPON_AMOUNT                   = 672;
    const PRODUCT_FIELD_ID_DAYS_VALID                      = 673;
    const PRODUCT_FIELD_ID_COUPON_DESCRIPTION              = 674;
    const PRODUCT_FIELD_ID_IS_SINGLE_PURPOSE_COUPON        = 675;
    const PRODUCT_FIELD_ID_SEND_MAIL                       = 676;
    const PRODUCT_FIELD_ID_USER_DELIVERY_TYPE_SELECT       = 678;
    const PRODUCT_FIELD_ID_USER_DELIVERY_TYPE_SELECT_ALLOW = 679;

    /**
     * Model constructor
     *
     * @param integer $pid - Product-ID
     * @param array $product - Product Data
     *
     * @throws QUI\ERP\Products\Product\Exception
     * @throws QUI\Exception
     */
    public function __construct($pid, $product = [])
    {
        parent::__construct($pid, $product);

        if (!empty($this->fields[self::PRODUCT_FIELD_ID_USER_DELIVERY_TYPE_SELECT_ALLOW])) {
            $userDeliveryTypeSelectAllow = $this->getFieldValue(
                self::PRODUCT_FIELD_ID_USER_DELIVERY_TYPE_SELECT_ALLOW
            );

            if ($userDeliveryTypeSelectAllow) {
                try {
                    $Field = QUI\ERP\Products\Handler\Fields::getField(
                        self::PRODUCT_FIELD_ID_USER_DELIVERY_TYPE_SELECT
                    );

                    $Field->setProduct($this);

                    $this->fields[$Field->getId()] = $Field;
                } catch (QUI\Exception $Exception) {
                    QUI\System\Log::writeException($Exception);
                }
            } else {
                unset($this->fields[self::PRODUCT_FIELD_ID_USER_DELIVERY_TYPE_SELECT]);
            }
        }
    }

    /**
     * @param QUI\Locale $Locale
     * @return string
     */
    public static function getTypeTitle($Locale = null)
    {
        if ($Locale === null) {
            $Locale = QUI::getLocale();
        }

        return $Locale->get('quiqqer/coupons', 'product_type.CouponProductType.title');
    }

    /**
     * @param QUI\Locale $Locale
     * @return string
     */
    public static function getTypeDescription($Locale = null)
    {
        if ($Locale === null) {
            $Locale = QUI::getLocale();
        }

        return $Locale->get('quiqqer/coupons', 'product_type.CouponProductType.description');
    }
}
